==> cost-main-rpc-1.5.0-sources.jar: com/chinayanghe/tpm/rpc/vo/budget/BudgetVo.java <==
package com.chinayanghe.tpm.rpc.vo.budget;

import java.io.Serializable;

public class BudgetVo implements Serializable {
//    广告--2101
//    一桌式品鉴--2119
//    客情礼品/旅游--2108
//    来宾接待--2125
//    门头牌--2121
//    渠道赠饮--2110
//    微分子赠酒--2124

    /**
     * 是否包括广告
     */
    private Boolean boolean2101 = Boolean.FALSE;
    private Boolean boolean2119 = Boolean.FALSE;

    private Boolean boolean2108 = Boolean.FALSE;

    private Boolean boolean2125 = Boolean.FALSE;
    private Boolean boolean2121 = Boolean.FALSE;
    private Boolean boolean2110 = Boolean.FALSE;
    private Boolean boolean2124 = Boolean.FALSE;

    /**
     * 经销商转分公司统筹
     */
    private Boolean booleanTotal = Boolean.FALSE;


    public Boolean getBoolean2101() {
        return boolean2101;
    }

    public void setBoolean2101(Boolean boolean2101) {
        this.boolean2101 = boolean2101;
    }

    public Boolean getBoolean2119() {
        return boolean2119;
    }

    public void setBoolean2119(Boolean boolean2119) {
        this.boolean2119 = boolean2119;
    }

    public Boolean getBoolean2108() {
        return boolean2108;
    }

    public void setBoolean2108(Boolean boolean2108) {
        this.boolean2108 = boolean2108;
    }

    public Boolean getBoolean2125() {
        return boolean2125;
    }

    public void setBoolean2125(Boolean boolean2125) {
        this.boolean2125 = boolean2125;
    }

    public Boolean getBoolean2121() {
        return boolean2121;
    }

    public void setBoolean2121(Boolean boolean2121) {
        this.boolean2121 = boolean2121;
    }

    public Boolean getBoolean2110() {
        return boolean2110;
    }

    public void setBoolean2110(Boolean boolean2110) {
        this.boolean2110 = boolean2110;
    }

    public Boolean getBoolean2124() {
        return boolean2124;
    }

    public void setBoolean2124(Boolean boolean2124) {
        this.boolean2124 = boolean2124;
    }

    public Boolean getBooleanTotal() {
        return booleanTotal;
    }

    public void setBooleanTotal(Boolean booleanTotal) {
        this.booleanTotal = booleanTotal;
    }
}

==> cost-main-rpc-1.6.9-sources.jar: com/chinayanghe/tpm/rpc/vo/budget/BudgetVo.java <==
package com.chinayanghe.tpm.rpc.vo.budget;

import java.io.Serializable;

public class BudgetVo implements Serializable {
//    广告--2101
//    一桌式品鉴--2119
//    客情礼品/旅游--2108
//    来宾接待--2125
//    门头牌--2121
//    渠道赠饮--2110
//    微分子赠酒--2124

    /**
     * 是否包括广告
     */
    private Boolean boolean2101 = Boolean.FALSE;
    private Boolean boolean2119 = Boolean.FALSE;

    private Boolean boolean2108 = Boolean.FALSE;

    private Boolean boolean2125 = Boolean.FALSE;
    private Boolean boolean2121 = Boolean.FALSE;
    private Boolean boolean2110 = Boolean.FALSE;
    private Boolean boolean2124 = Boolean.FALSE;

    /**
     * 转入葡萄酒
     */
    private Boolean booleanWine = Boolean.FALSE;
    /**
     * 经销商转分公司统筹
     */
    private Boolean booleanTotal = Boolean.FALSE;


    public Boolean getBooleanWine() {
        return booleanWine;
    }
    public void setBooleanWine(Boolean booleanWine) {
        this.booleanWine = booleanWine;
    }


    public Boolean getBoolean2101() {
        return boolean2101;
    }

    public void setBoolean2101(Boolean boolean2101) {
        this.boolean2101 = boolean2101;
    }

    public Boolean getBoolean2119() {
        return boolean2119;
    }

    public void setBoolean2119(Boolean boolean2119) {
        this.boolean2119 = boolean2119;
    }

    public Boolean getBoolean2108() {
        return boolean2108;
    }

    public void setBoolean2108(Boolean boolean2108) {
        this.boolean2108 = boolean2108;
    }

    public Boolean getBoolean2125() {
        return boolean2125;
    }

    public void setBoolean2125(Boolean boolean2125) {
        this.boolean2125 = boolean2125;
    }

    public Boolean getBoolean2121() {
        return boolean2121;
    }

    public void setBoolean2121(Boolean boolean2121) {
        this.boolean2121 = boolean2121;
    }

    public Boolean getBoolean2110() {
        return boolean2110;
    }

    public void setBoolean2110(Boolean boolean2110) {
        this.boolean2110 = boolean2110;
    }

    public Boolean getBoolean2124() {
        return boolean2124;
    }

    public void setBoolean2124(Boolean boolean2124) {
        this.boolean2124 = boolean2124;
    }

    public Boolean getBooleanTotal() {
        return booleanTotal;
    }

    public void setBooleanTotal(Boolean booleanTotal) {
        this.booleanTotal = booleanTotal;
    }
}
